From c3b024e99baf8d27ae1554b0dd0ef061f82b64ee Mon Sep 17 00:00:00 2001
From: Aaron Durbin <adurbin@chromium.org>
Date: Mon, 15 Aug 2016 14:13:05 -0500
Subject: Revert "Kconfig: separate memory mapped boot device from SPI"

This reverts commit a83bbf58541cf41ea7a97dedbc8c02dffa59e86d.
This was submitted out of order.

Change-Id: Ic5a28faf94c1f1901a72e46343722eb4224c5086
Signed-off-by: Aaron Durbin <adurbin@chromium.org>
Reviewed-on: https://review.coreboot.org/16226
Reviewed-by: Paul Menzel <paulepanter@users.sourceforge.net>
Reviewed-by: Nico Huber <nico.h@gmx.de>
---
 src/drivers/elog/elog.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

(limited to 'src/drivers/elog')

diff --git a/src/drivers/elog/elog.c b/src/drivers/elog/elog.c
index f046a3483b..55b8974304 100644
--- a/src/drivers/elog/elog.c
+++ b/src/drivers/elog/elog.c
@@ -586,8 +586,8 @@ static int elog_shrink(void)
  */
 static inline u8 *elog_flash_offset_to_address(void)
 {
-	/* Only support memory-mapped devices. */
-	if (!IS_ENABLED(CONFIG_BOOT_DEVICE_MEMORY_MAPPED))
+	/* Only support memory-mapped SPI devices. */
+	if (!IS_ENABLED(CONFIG_SPI_FLASH_MEMORY_MAPPED))
 		return NULL;
 
 	if (!elog_spi)
-- 
cgit v1.2.3